@@ -52,7 +52,7 @@
   (defun-maybe Meadow-version ()))
 
 (product-provide 'weather-version
-  (product-define "Weather" nil '(0 28)))
+  (product-define "Weather" nil '(0 29)))
 
 (defvar weather-insert-user-agent nil)
 
@@ -64,6 +64,7 @@
 (defvar weather-proxy-server nil)
 (defvar weather-proxy-port 3128)
 
+(defvar weather-debug nil)
 (defvar weather-timeout 20)
 (defvar weather-cache nil)
 
@@ -250,7 +251,8 @@
 					    (weather-port))))
 	      (if (null connection)
 		  (progn
-		    (if buf (kill-buffer buf))
+		    (if (and buf (null weather-debug))
+			(kill-buffer buf))
 		    (weather-sleep)
 		    (throw 'done nil))))
 	    (unwind-protect
@@ -278,6 +280,7 @@
 		   connection "\r\n")
 		  (set-buffer buf)
 		  (setq buffer-read-only nil)
+		  (setq case-fold-search t)
 		  (goto-char (point-min))
 		  (while (not (search-forward "</body>" nil t))
 		    (unwind-protect
@@ -285,14 +288,15 @@
 			      (accept-process-output connection weather-timeout))
 		      (if (null ret-val)
 			  (progn
-			    (if buf (kill-buffer buf))
+			    (if (and buf (null weather-debug))
+				(kill-buffer buf))
 			    (if connection (delete-process connection))
 			    (weather-sleep)
 			    (throw 'done nil))))
 		    (goto-char (point-min)))
 		  (decode-coding-region (point-min)(point-max)
 					weather-coding-system)
-		  (goto-char  (point-min))
+		  (goto-char (point-min))
 		  (setq date
 			(if (re-search-forward
 			     "$B=54VE75$M=Js(B[^0-9]*[ 0-9]+$B7n(B\\([ 0-9]+\\)$BF|(B\\([ 0-9]+\\)$B;~(B" nil t)
@@ -308,7 +312,7 @@
 				       nil t)
 		    (weather-set-cache ret-val date
 				       (match-string 2))))
-	      (if buf (kill-buffer buf))
+	      (if (and buf (null weather-debug)) (kill-buffer buf))
 	      (if connection (delete-process connection))))))))
 
 (defun weather-from-http (&optional where offline)
